summaryrefslogtreecommitdiffstats
path: root/src/3rdparty/libmng/ltmain.sh
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 22:04:08 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 22:04:08 -0600
commite02e31c8b9d854cd62cbe9799228f6e08e882773 (patch)
tree53303c981d0b20e03c5a2fc8e959fa74adcb90d1 /src/3rdparty/libmng/ltmain.sh
parent143f194af098d44bf0dd1ebb29e59f30ce48d523 (diff)
downloadtqt3-e02e31c8b9d854cd62cbe9799228f6e08e882773.tar.gz
tqt3-e02e31c8b9d854cd62cbe9799228f6e08e882773.zip
Sync with latest script
Diffstat (limited to 'src/3rdparty/libmng/ltmain.sh')
-rw-r--r--src/3rdparty/libmng/ltmain.sh24
1 files changed, 12 insertions, 12 deletions
diff --git a/src/3rdparty/libmng/ltmain.sh b/src/3rdparty/libmng/ltmain.sh
index 663ed35d6..59b9650b0 100644
--- a/src/3rdparty/libmng/ltmain.sh
+++ b/src/3rdparty/libmng/ltmain.sh
@@ -200,7 +200,7 @@ do
done
if test -n "$prevopt"; then
- $echo "$modename: option \`$prevopt' retquires an argument" 1>&2
+ $echo "$modename: option \`$prevopt' requires an argument" 1>&2
$echo "$help" 1>&2
exit 1
fi
@@ -1073,7 +1073,7 @@ compiler."
-no-install)
case $host in
*-*-cygwin* | *-*-mingw* | *-*-pw32* | *-*-os2*)
# The PATH hackery in wrapper scripts is retquired on Windows
# in order for the loader to find any dlls it needs.
$echo "$modename: warning: \`-no-install' is ignored for $host" 1>&2
$echo "$modename: warning: assuming \`-no-fast-install' instead" 1>&2
@@ -1272,7 +1272,7 @@ compiler."
done # argument parsing loop
if test -n "$prev"; then
- $echo "$modename: the \`$prevarg' option retquires an argument" 1>&2
+ $echo "$modename: the \`$prevarg' option requires an argument" 1>&2
$echo "$help" 1>&2
exit 1
fi
@@ -1633,7 +1633,7 @@ compiler."
exit 1
fi
# Prefer using a static library (so that no silly _DYNAMIC symbols
# are retquired to link).
if test -n "$old_library"; then
newdlprefiles="$newdlprefiles $dir/$old_library"
# Otherwise, use the dlname, so that lt_dlopen finds it.
@@ -2147,7 +2147,7 @@ compiler."
exit 1
fi
if test "$need_lib_prefix" != no; then
# Add the "lib" prefix for modules if retquired
name=`$echo "X$outputname" | $Xsed -e 's/\.la$//'`
eval libname=\"$libname_spec\"
else
@@ -3396,7 +3396,7 @@ static const void *lt_preloaded_setup() {
else
# We keep going just in case the user didn't refer to
# lt_preloaded_symbols. The linker will fail if global_symbol_pipe
# really was retquired.
# Nullify the symbol file.
compile_command=`$echo "X$compile_command" | $Xsed -e "s% @SYMFILE@%%"`
@@ -4054,7 +4054,7 @@ relink_command=\"$relink_command\""
fi
if test -n "$prev"; then
- $echo "$modename: the \`$prev' option retquires an argument" 1>&2
+ $echo "$modename: the \`$prev' option requires an argument" 1>&2
$echo "$help" 1>&2
exit 1
fi
@@ -4873,7 +4873,7 @@ This mode sets the library path environment variable according to \`-dlopen'
flags.
If any of the ARGS are libtool executable wrappers, then they are translated
-into their corresponding uninstalled binary, and any of their retquired library
+into their corresponding uninstalled binary, and any of their required library
directories are added to the library path.
Then, COMMAND is executed, with ARGS as arguments."
@@ -4887,7 +4887,7 @@ Complete the installation of libtool libraries.
Each LIBDIR is a directory that contains libtool libraries.
-The commands that this mode executes may retquire superuser privileges. Use
+The commands that this mode executes may require superuser privileges. Use
the \`--dry-run' option if you just want to see what would be executed."
;;
@@ -4925,8 +4925,8 @@ The following components of LINK-COMMAND are treated specially:
try to export only the symbols listed in SYMFILE
-export-symbols-regex REGEX
try to export only the symbols matching REGEX
- -LLIBDIR search LIBDIR for retquired installed libraries
- -lNAME OUTPUT-FILE retquires the installed library libNAME
+ -LLIBDIR search LIBDIR for required installed libraries
+ -lNAME OUTPUT-FILE requires the installed library libNAME
-module build a library that can dlopened
-no-fast-install disable the fast-install mode
-no-install link a not-installable executable
@@ -4947,7 +4947,7 @@ object files.
If the OUTPUT-FILE ends in \`.la', then a libtool library is created,
only library objects (\`.lo' files) may be specified, and \`-rpath' is
-retquired, except when creating a convenience library.
+required, except when creating a convenience library.
If OUTPUT-FILE ends in \`.a' or \`.lib', then a standard library is created
using \`ar' and \`ranlib', or on Windows using \`lib'.
@@ -1073,7 +1073,7 @@ compiler."
case $host in
*-*-cygwin* | *-*-mingw* | *-*-pw32* | *-*-os2*)
- # The PATH hackery in wrapper scripts is retquired on Windows
+ # The PATH hackery in wrapper scripts is required on Windows
# in order for the loader to find any dlls it needs.
$echo "$modename: warning: \`-no-install' is ignored for $host" 1>&2
@@ -1633,7 +1633,7 @@ compiler."
fi
# Prefer using a static library (so that no silly _DYNAMIC symbols
- # are retquired to link).
+ # are required to link).
if test -n "$old_library"; then
newdlprefiles="$newdlprefiles $dir/$old_library"
@@ -2147,7 +2147,7 @@ compiler."
fi
if test "$need_lib_prefix" != no; then
- # Add the "lib" prefix for modules if retquired
+ # Add the "lib" prefix for modules if required
name=`$echo "X$outputname" | $Xsed -e 's/\.la$//'`
eval libname=\"$libname_spec\"
@@ -3396,7 +3396,7 @@ static const void *lt_preloaded_setup() {
# We keep going just in case the user didn't refer to
# lt_preloaded_symbols. The linker will fail if global_symbol_pipe
- # really was retquired.
+ # really was required.
# Nullify the symbol file.
compile_command=`$echo "X$compile_command" | $Xsed -e "s% @SYMFILE@%%"`